# Tract internals documentation

This kind of documentation does not tend to age well. Use with caution.

* a [tract crates introduction](intro.md)
* a [tract command line cookbook](cli-recipe.md)
* [graph, model, node, op, facts](graph.md)
